/* notificationbar.c generated by valac 0.36.1.38-6532, the Vala compiler
 * generated from notificationbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
typedef struct _BoxesNotificationbarPrivate BoxesNotificationbarPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;
enum  {
	BOXES_NOTIFICATIONBAR_DUMMY_PROPERTY,
	BOXES_NOTIFICATIONBAR_LAST_PROPERTY
};
static GParamSpec* boxes_notificationbar_properties[BOXES_NOTIFICATIONBAR_LAST_PROPERTY];
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_NOTIFICATION (boxes_notification_get_type ())
#define BOXES_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotification))
#define BOXES_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))
#define BOXES_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATION))
#define BOXES_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATION))
#define BOXES_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))

typedef struct _BoxesNotification BoxesNotification;
typedef struct _BoxesNotificationClass BoxesNotificationClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block66Data Block66Data;

#define BOXES_TYPE_AUTH_NOTIFICATION (boxes_auth_notification_get_type ())
#define BOXES_AUTH_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_AUTH_NOTIFICATION, BoxesAuthNotification))
#define BOXES_AUTH_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_AUTH_NOTIFICATION, BoxesAuthNotificationClass))
#define BOXES_IS_AUTH_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_AUTH_NOTIFICATION))
#define BOXES_IS_AUTH_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_AUTH_NOTIFICATION))
#define BOXES_AUTH_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_AUTH_NOTIFICATION, BoxesAuthNotificationClass))

typedef struct _BoxesAuthNotification BoxesAuthNotification;
typedef struct _BoxesAuthNotificationClass BoxesAuthNotificationClass;
typedef struct _Block67Data Block67Data;
typedef struct _Block68Data Block68Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

struct _BoxesNotificationbar {
	GtkGrid parent_instance;
	BoxesNotificationbarPrivate * priv;
	BoxesSearchbar* searchbar;
};

struct _BoxesNotificationbarClass {
	GtkGridClass parent_class;
};

struct _BoxesNotificationbarPrivate {
	GList* active_notifications;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationDismissFunc) (void* user_data);
typedef void (*BoxesAuthNotificationAuthFunc) (const gchar* username, const gchar* password, void* user_data);
struct _Block66Data {
	int _ref_count_;
	BoxesNotificationbar* self;
	gchar* broker_name;
	BoxesAuthNotificationAuthFunc auth_func;
	gpointer auth_func_target;
	GDestroyNotify auth_func_target_destroy_notify;
	BoxesNotificationDismissFunc dismiss_func;
	gpointer dismiss_func_target;
	GDestroyNotify dismiss_func_target_destroy_notify;
};

struct _Block67Data {
	int _ref_count_;
	BoxesNotificationbar* self;
	BoxesAuthNotification* notification;
};

struct _Block68Data {
	int _ref_count_;
	BoxesNotificationbar* self;
	BoxesNotification* notification;
};


static gpointer boxes_notificationbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
#define BOXES_NOTIFICATIONBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarPrivate))
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
#define BOXES_NOTIFICATIONBAR_MAX_NOTIFICATIONS 5
GType boxes_notification_get_type (void) G_GNUC_CONST;
BoxesNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationDismissFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static BoxesNotification* boxes_notificationbar_display (BoxesNotificationbar* self, const gchar* message, GtkMessageType message_type, const gchar* ok_label, BoxesNotificationOKFunc ok_func, void* ok_func_target, GDestroyNotify ok_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify, gint timeout);
BoxesNotification* boxes_notificationbar_display_for_optional_auth (BoxesNotificationbar* self, const gchar* broker_name, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify);
static Block66Data* block66_data_ref (Block66Data* _data66_);
static void block66_data_unref (void * _userdata_);
static void __lambda44_ (Block66Data* _data66_);
GType boxes_auth_notification_get_type (void) G_GNUC_CONST;
BoxesAuthNotification* boxes_notificationbar_display_for_auth (BoxesNotificationbar* self, const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify, gboolean need_username);
static void ___lambda44__boxes_notification_ok_func (gpointer self);
static Block67Data* block67_data_ref (Block67Data* _data67_);
static void block67_data_unref (void * _userdata_);
BoxesAuthNotification* boxes_auth_notification_new (const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify, gboolean need_username, BoxesSearchbar* searchbar);
BoxesAuthNotification* boxes_auth_notification_construct (GType object_type, const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify, gboolean need_username, BoxesSearchbar* searchbar);
static void __lambda46_ (Block67Data* _data67_);
static void ___lambda46__boxes_auth_notification_dismissed (BoxesAuthNotification* _sender, gpointer self);
static void boxes_notificationbar_add_notification (BoxesNotificationbar* self, GtkWidget* w);
BoxesNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
void boxes_notificationbar_dismiss_all (BoxesNotificationbar* self);
static Block68Data* block68_data_ref (Block68Data* _data68_);
static void block68_data_unref (void * _userdata_);
BoxesNotification* boxes_notification_new (const gchar* message, GtkMessageType message_type, const gchar* ok_label, BoxesNotificationOKFunc ok_func, void* ok_func_target, GDestroyNotify ok_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify, gint timeout);
BoxesNotification* boxes_notification_construct (GType object_type, const gchar* message, GtkMessageType message_type, const gchar* ok_label, BoxesNotificationOKFunc ok_func, void* ok_func_target, GDestroyNotify ok_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify, gint timeout);
void boxes_notification_dismiss (BoxesNotification* self);
static void __lambda43_ (Block68Data* _data68_);
static void ___lambda43__boxes_notification_dismissed (BoxesNotification* _sender, gpointer self);
BoxesNotificationbar* boxes_notificationbar_new (void);
BoxesNotificationbar* boxes_notificationbar_construct (GType object_type);
static GObject * boxes_notificationbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void _boxes_notificationbar___lambda47_ (BoxesNotificationbar* self);
static void __boxes_notificationbar___lambda47__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_notificationbar_finalize (GObject * obj);


static void _g_object_unref0_ (gpointer var) {
#line 8 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 167 "notificationbar.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 8 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 174 "notificationbar.c"
}


BoxesNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationDismissFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout) {
	BoxesNotification* result = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	BoxesNotificationOKFunc _tmp2_;
	void* _tmp2__target;
	GDestroyNotify _tmp2__target_destroy_notify;
	BoxesNotificationDismissFunc _tmp3_;
	void* _tmp3__target;
	GDestroyNotify _tmp3__target_destroy_notify;
	gint _tmp4_;
	BoxesNotification* _tmp5_;
#line 32 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 32 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 32 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (action_label != NULL, NULL);
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = message;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = action_label;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = action_func;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2__target = action_func_target;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2__target_destroy_notify = action_func_target_destroy_notify;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	action_func = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	action_func_target = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	action_func_target_destroy_notify = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = ignore_func;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3__target = ignore_func_target;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3__target_destroy_notify = ignore_func_target_destroy_notify;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ignore_func = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ignore_func_target = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ignore_func_target_destroy_notify = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = timeout;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = boxes_notificationbar_display (self, _tmp0_, GTK_MESSAGE_INFO, _tmp1_, _tmp2_, _tmp2__target, _tmp2__target_destroy_notify, _tmp3_, _tmp3__target, _tmp3__target_destroy_notify, _tmp4_);
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	result = _tmp5_;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(action_func_target_destroy_notify == NULL) ? NULL : (action_func_target_destroy_notify (action_func_target), NULL);
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	action_func = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	action_func_target = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	action_func_target_destroy_notify = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(ignore_func_target_destroy_notify == NULL) ? NULL : (ignore_func_target_destroy_notify (ignore_func_target), NULL);
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ignore_func = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ignore_func_target = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ignore_func_target_destroy_notify = NULL;
#line 37 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return result;
#line 248 "notificationbar.c"
}


static Block66Data* block66_data_ref (Block66Data* _data66_) {
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_atomic_int_inc (&_data66_->_ref_count_);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return _data66_;
#line 257 "notificationbar.c"
}


static void block66_data_unref (void * _userdata_) {
	Block66Data* _data66_;
	_data66_ = (Block66Data*) _userdata_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	if (g_atomic_int_dec_and_test (&_data66_->_ref_count_)) {
#line 266 "notificationbar.c"
		BoxesNotificationbar* self;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		self = _data66_->self;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_g_free0 (_data66_->broker_name);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		(_data66_->auth_func_target_destroy_notify == NULL) ? NULL : (_data66_->auth_func_target_destroy_notify (_data66_->auth_func_target), NULL);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_data66_->auth_func = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_data66_->auth_func_target = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_data66_->auth_func_target_destroy_notify = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		(_data66_->dismiss_func_target_destroy_notify == NULL) ? NULL : (_data66_->dismiss_func_target_destroy_notify (_data66_->dismiss_func_target), NULL);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_data66_->dismiss_func = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_data66_->dismiss_func_target = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_data66_->dismiss_func_target_destroy_notify = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (self);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		g_slice_free (Block66Data, _data66_);
#line 292 "notificationbar.c"
	}
}


static void __lambda44_ (Block66Data* _data66_) {
	BoxesNotificationbar* self;
	gchar* auth_string = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	BoxesAuthNotificationAuthFunc _tmp7_;
	void* _tmp7__target;
	GDestroyNotify _tmp7__target_destroy_notify;
	BoxesNotificationDismissFunc _tmp8_;
	void* _tmp8__target;
	GDestroyNotify _tmp8__target_destroy_notify;
	BoxesAuthNotification* _tmp9_;
	BoxesAuthNotification* _tmp10_;
#line 43 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self = _data66_->self;
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = _data66_->broker_name;
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = g_strdup_printf (_ ("Sign In to %s"), _tmp0_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = _tmp1_;
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = g_strconcat ("<span font-weight=\"bold\">", _tmp2_, NULL);
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = _tmp3_;
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = g_strconcat (_tmp4_, "</span>", NULL);
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp6_ = _tmp5_;
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_g_free0 (_tmp4_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_g_free0 (_tmp2_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	auth_string = _tmp6_;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp7_ = _data66_->auth_func;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp7__target = _data66_->auth_func_target;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp7__target_destroy_notify = _data66_->auth_func_target_destroy_notify;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func = NULL;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func_target = NULL;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func_target_destroy_notify = NULL;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp8_ = _data66_->dismiss_func;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp8__target = _data66_->dismiss_func_target;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp8__target_destroy_notify = _data66_->dismiss_func_target_destroy_notify;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func = NULL;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func_target = NULL;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func_target_destroy_notify = NULL;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp9_ = boxes_notificationbar_display_for_auth (self, auth_string, _tmp7_, _tmp7__target, _tmp7__target_destroy_notify, _tmp8_, _tmp8__target, _tmp8__target_destroy_notify, TRUE);
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp10_ = _tmp9_;
#line 45 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (_tmp10_);
#line 43 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_g_free0 (auth_string);
#line 369 "notificationbar.c"
}


static void ___lambda44__boxes_notification_ok_func (gpointer self) {
#line 43 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	__lambda44_ (self);
#line 376 "notificationbar.c"
}


BoxesNotification* boxes_notificationbar_display_for_optional_auth (BoxesNotificationbar* self, const gchar* broker_name, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify) {
	BoxesNotification* result = NULL;
	Block66Data* _data66_;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	BoxesAuthNotificationAuthFunc _tmp2_;
	void* _tmp2__target;
	BoxesNotificationDismissFunc _tmp3_;
	void* _tmp3__target;
	BoxesNotificationOKFunc next_auth_step = NULL;
	void* next_auth_step_target;
	GDestroyNotify next_auth_step_target_destroy_notify;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	BoxesNotificationOKFunc _tmp7_;
	void* _tmp7__target;
	GDestroyNotify _tmp7__target_destroy_notify;
	BoxesNotificationDismissFunc _tmp8_;
	void* _tmp8__target;
	GDestroyNotify _tmp8__target_destroy_notify;
	BoxesNotification* _tmp9_;
	BoxesNotification* _tmp10_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (broker_name != NULL, NULL);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_ = g_slice_new0 (Block66Data);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->_ref_count_ = 1;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->self = g_object_ref (self);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = broker_name;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_g_free0 (_data66_->broker_name);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->broker_name = _tmp1_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = auth_func;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2__target = auth_func_target;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(_data66_->auth_func_target_destroy_notify == NULL) ? NULL : (_data66_->auth_func_target_destroy_notify (_data66_->auth_func_target), NULL);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func_target = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func_target_destroy_notify = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func = _tmp2_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func_target = _tmp2__target;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->auth_func_target_destroy_notify = auth_func_target_destroy_notify;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = dismiss_func;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3__target = dismiss_func_target;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(_data66_->dismiss_func_target_destroy_notify == NULL) ? NULL : (_data66_->dismiss_func_target_destroy_notify (_data66_->dismiss_func_target), NULL);
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func_target = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func_target_destroy_notify = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func = _tmp3_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func_target = _tmp3__target;
#line 40 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func_target_destroy_notify = dismiss_func_target_destroy_notify;
#line 43 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step = ___lambda44__boxes_notification_ok_func;
#line 43 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target = block66_data_ref (_data66_);
#line 43 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target_destroy_notify = block66_data_unref;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = _data66_->broker_name;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = g_strdup_printf (_ ("Not connected to %s"), _tmp4_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp6_ = _tmp5_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp7_ = next_auth_step;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp7__target = next_auth_step_target;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp7__target_destroy_notify = next_auth_step_target_destroy_notify;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target_destroy_notify = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp8_ = _data66_->dismiss_func;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp8__target = _data66_->dismiss_func_target;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp8__target_destroy_notify = _data66_->dismiss_func_target_destroy_notify;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func_target = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_->dismiss_func_target_destroy_notify = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp9_ = boxes_notificationbar_display_for_action (self, _tmp6_, _ ("Sign In"), _tmp7_, _tmp7__target, _tmp7__target_destroy_notify, _tmp8_, _tmp8__target, _tmp8__target_destroy_notify, -1);
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp10_ = _tmp9_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_g_free0 (_tmp6_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	result = _tmp10_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(next_auth_step_target_destroy_notify == NULL) ? NULL : (next_auth_step_target_destroy_notify (next_auth_step_target), NULL);
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	next_auth_step_target_destroy_notify = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	block66_data_unref (_data66_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data66_ = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return result;
#line 515 "notificationbar.c"
}


static Block67Data* block67_data_ref (Block67Data* _data67_) {
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_atomic_int_inc (&_data67_->_ref_count_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return _data67_;
#line 524 "notificationbar.c"
}


static void block67_data_unref (void * _userdata_) {
	Block67Data* _data67_;
	_data67_ = (Block67Data*) _userdata_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	if (g_atomic_int_dec_and_test (&_data67_->_ref_count_)) {
#line 533 "notificationbar.c"
		BoxesNotificationbar* self;
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		self = _data67_->self;
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (_data67_->notification);
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (self);
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		g_slice_free (Block67Data, _data67_);
#line 543 "notificationbar.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 63 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 551 "notificationbar.c"
}


static void __lambda46_ (Block67Data* _data67_) {
	BoxesNotificationbar* self;
#line 65 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self = _data67_->self;
#line 66 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = g_list_remove (self->priv->active_notifications, (GtkWidget*) _data67_->notification);
#line 561 "notificationbar.c"
}


static void ___lambda46__boxes_auth_notification_dismissed (BoxesAuthNotification* _sender, gpointer self) {
#line 65 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	__lambda46_ (self);
#line 568 "notificationbar.c"
}


BoxesAuthNotification* boxes_notificationbar_display_for_auth (BoxesNotificationbar* self, const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify, gboolean need_username) {
	BoxesAuthNotification* result = NULL;
	Block67Data* _data67_;
	const gchar* _tmp0_;
	BoxesAuthNotificationAuthFunc _tmp1_;
	void* _tmp1__target;
	GDestroyNotify _tmp1__target_destroy_notify;
	BoxesNotificationDismissFunc _tmp2_;
	void* _tmp2__target;
	GDestroyNotify _tmp2__target_destroy_notify;
	gboolean _tmp3_;
	BoxesSearchbar* _tmp4_;
	BoxesAuthNotification* _tmp5_;
	GtkWidget* _tmp6_;
	BoxesAuthNotification* _tmp7_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (auth_string != NULL, NULL);
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data67_ = g_slice_new0 (Block67Data);
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data67_->_ref_count_ = 1;
#line 53 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data67_->self = g_object_ref (self);
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = auth_string;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = auth_func;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1__target = auth_func_target;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1__target_destroy_notify = auth_func_target_destroy_notify;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	auth_func = NULL;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	auth_func_target = NULL;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	auth_func_target_destroy_notify = NULL;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = dismiss_func;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2__target = dismiss_func_target;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2__target_destroy_notify = dismiss_func_target_destroy_notify;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func = NULL;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func_target = NULL;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func_target_destroy_notify = NULL;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = need_username;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = self->searchbar;
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = boxes_auth_notification_new (_tmp0_, _tmp1_, _tmp1__target, _tmp1__target_destroy_notify, _tmp2_, _tmp2__target, _tmp2__target_destroy_notify, _tmp3_, _tmp4_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp5_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data67_->notification = _tmp5_;
#line 63 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp6_ = _g_object_ref0 ((GtkWidget*) _data67_->notification);
#line 63 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = g_list_prepend (self->priv->active_notifications, _tmp6_);
#line 65 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_data (_data67_->notification, "dismissed", (GCallback) ___lambda46__boxes_auth_notification_dismissed, block67_data_ref (_data67_), (GClosureNotify) block67_data_unref, 0);
#line 69 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	boxes_notificationbar_add_notification (self, (GtkWidget*) _data67_->notification);
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp7_ = _g_object_ref0 (_data67_->notification);
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	result = _tmp7_;
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	block67_data_unref (_data67_);
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data67_ = NULL;
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(auth_func_target_destroy_notify == NULL) ? NULL : (auth_func_target_destroy_notify (auth_func_target), NULL);
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	auth_func = NULL;
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	auth_func_target = NULL;
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	auth_func_target_destroy_notify = NULL;
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(dismiss_func_target_destroy_notify == NULL) ? NULL : (dismiss_func_target_destroy_notify (dismiss_func_target), NULL);
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func = NULL;
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func_target = NULL;
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func_target_destroy_notify = NULL;
#line 71 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return result;
#line 667 "notificationbar.c"
}


BoxesNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout) {
	BoxesNotification* result = NULL;
	const gchar* _tmp0_;
	gint _tmp1_;
	BoxesNotification* _tmp2_;
#line 74 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 74 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 75 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = message;
#line 75 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = timeout;
#line 75 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = boxes_notificationbar_display (self, _tmp0_, GTK_MESSAGE_ERROR, NULL, NULL, NULL, NULL, NULL, NULL, NULL, _tmp1_);
#line 75 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	result = _tmp2_;
#line 75 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return result;
#line 690 "notificationbar.c"
}


void boxes_notificationbar_dismiss_all (BoxesNotificationbar* self) {
#line 78 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_if_fail (self != NULL);
#line 80 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	while (TRUE) {
#line 699 "notificationbar.c"
		GList* _tmp0_;
		GList* _tmp1_;
		gconstpointer _tmp2_;
#line 80 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_tmp0_ = self->priv->active_notifications;
#line 80 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		if (!(_tmp0_ != NULL)) {
#line 80 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
			break;
#line 709 "notificationbar.c"
		}
#line 81 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_tmp1_ = self->priv->active_notifications;
#line 81 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_tmp2_ = _tmp1_->data;
#line 81 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp2_);
#line 717 "notificationbar.c"
	}
}


static void boxes_notificationbar_add_notification (BoxesNotificationbar* self, GtkWidget* w) {
	GtkWidget* _tmp0_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_if_fail (self != NULL);
#line 85 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_if_fail (w != NULL);
#line 86 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = w;
#line 86 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	gtk_container_add ((GtkContainer*) self, _tmp0_);
#line 732 "notificationbar.c"
}


static Block68Data* block68_data_ref (Block68Data* _data68_) {
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_atomic_int_inc (&_data68_->_ref_count_);
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return _data68_;
#line 741 "notificationbar.c"
}


static void block68_data_unref (void * _userdata_) {
	Block68Data* _data68_;
	_data68_ = (Block68Data*) _userdata_;
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	if (g_atomic_int_dec_and_test (&_data68_->_ref_count_)) {
#line 750 "notificationbar.c"
		BoxesNotificationbar* self;
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		self = _data68_->self;
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (_data68_->notification);
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_g_object_unref0 (self);
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		g_slice_free (Block68Data, _data68_);
#line 760 "notificationbar.c"
	}
}


static void __lambda43_ (Block68Data* _data68_) {
	BoxesNotificationbar* self;
	BoxesNotification* _tmp0_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self = _data68_->self;
#line 114 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = _data68_->notification;
#line 114 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = g_list_remove (self->priv->active_notifications, (GtkWidget*) _tmp0_);
#line 774 "notificationbar.c"
}


static void ___lambda43__boxes_notification_dismissed (BoxesNotification* _sender, gpointer self) {
#line 113 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	__lambda43_ (self);
#line 781 "notificationbar.c"
}


static BoxesNotification* boxes_notificationbar_display (BoxesNotificationbar* self, const gchar* message, GtkMessageType message_type, const gchar* ok_label, BoxesNotificationOKFunc ok_func, void* ok_func_target, GDestroyNotify ok_func_target_destroy_notify, BoxesNotificationDismissFunc dismiss_func, void* dismiss_func_target, GDestroyNotify dismiss_func_target_destroy_notify, gint timeout) {
	BoxesNotification* result = NULL;
	Block68Data* _data68_;
	const gchar* _tmp0_;
	GtkMessageType _tmp1_;
	const gchar* _tmp2_;
	BoxesNotificationOKFunc _tmp3_;
	void* _tmp3__target;
	GDestroyNotify _tmp3__target_destroy_notify;
	BoxesNotificationDismissFunc _tmp4_;
	void* _tmp4__target;
	GDestroyNotify _tmp4__target_destroy_notify;
	gint _tmp5_;
	BoxesNotification* _tmp6_;
	gint excess_notifications = 0;
	GList* _tmp7_;
	guint _tmp8_;
	BoxesNotification* _tmp21_;
	GtkWidget* _tmp22_;
	BoxesNotification* _tmp23_;
	BoxesNotification* _tmp24_;
	BoxesNotification* _tmp25_;
	BoxesNotification* _tmp26_;
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data68_ = g_slice_new0 (Block68Data);
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data68_->_ref_count_ = 1;
#line 89 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data68_->self = g_object_ref (self);
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = message;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = message_type;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp2_ = ok_label;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3_ = ok_func;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3__target = ok_func_target;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp3__target_destroy_notify = ok_func_target_destroy_notify;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ok_func = NULL;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ok_func_target = NULL;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ok_func_target_destroy_notify = NULL;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp4_ = dismiss_func;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp4__target = dismiss_func_target;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp4__target_destroy_notify = dismiss_func_target_destroy_notify;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func = NULL;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func_target = NULL;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func_target_destroy_notify = NULL;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp5_ = timeout;
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp6_ = boxes_notification_new (_tmp0_, _tmp1_, _tmp2_, _tmp3_, _tmp3__target, _tmp3__target_destroy_notify, _tmp4_, _tmp4__target, _tmp4__target_destroy_notify, _tmp5_);
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_object_ref_sink (_tmp6_);
#line 95 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data68_->notification = _tmp6_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp7_ = self->priv->active_notifications;
#line 102 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp8_ = g_list_length (_tmp7_);
#line 102 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	excess_notifications = (((gint) _tmp8_) - BOXES_NOTIFICATIONBAR_MAX_NOTIFICATIONS) + 1;
#line 862 "notificationbar.c"
	{
		gint i = 0;
		gint _tmp9_;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		_tmp9_ = excess_notifications;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		i = _tmp9_;
#line 870 "notificationbar.c"
		{
			gboolean _tmp10_ = FALSE;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
			_tmp10_ = TRUE;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
			while (TRUE) {
#line 877 "notificationbar.c"
				gint _tmp12_;
				BoxesNotification* last_notification = NULL;
				GList* _tmp13_;
				GList* _tmp14_;
				guint _tmp15_;
				gint _tmp16_;
				gconstpointer _tmp17_;
				GtkWidget* _tmp18_;
				BoxesNotification* _tmp19_;
				BoxesNotification* _tmp20_;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				if (!_tmp10_) {
#line 890 "notificationbar.c"
					gint _tmp11_;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
					_tmp11_ = i;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
					i = _tmp11_ - 1;
#line 896 "notificationbar.c"
				}
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp10_ = FALSE;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp12_ = i;
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				if (!(_tmp12_ > 0)) {
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
					break;
#line 906 "notificationbar.c"
				}
#line 105 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp13_ = self->priv->active_notifications;
#line 105 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp14_ = self->priv->active_notifications;
#line 105 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp15_ = g_list_length (_tmp14_);
#line 105 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp16_ = i;
#line 105 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp17_ = g_list_nth_data (_tmp13_, _tmp15_ - _tmp16_);
#line 105 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp18_ = (GtkWidget*) _tmp17_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp19_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, BOXES_TYPE_NOTIFICATION) ? ((BoxesNotification*) _tmp18_) : NULL);
#line 105 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				last_notification = _tmp19_;
#line 108 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp20_ = last_notification;
#line 108 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				boxes_notification_dismiss (_tmp20_);
#line 104 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_g_object_unref0 (last_notification);
#line 930 "notificationbar.c"
			}
		}
	}
#line 111 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp21_ = _data68_->notification;
#line 111 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp22_ = _g_object_ref0 ((GtkWidget*) _tmp21_);
#line 111 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = g_list_prepend (self->priv->active_notifications, _tmp22_);
#line 113 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp23_ = _data68_->notification;
#line 113 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_data (_tmp23_, "dismissed", (GCallback) ___lambda43__boxes_notification_dismissed, block68_data_ref (_data68_), (GClosureNotify) block68_data_unref, 0);
#line 117 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp24_ = _data68_->notification;
#line 117 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	boxes_notificationbar_add_notification (self, (GtkWidget*) _tmp24_);
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp25_ = _data68_->notification;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp26_ = _g_object_ref0 (_tmp25_);
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	result = _tmp26_;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	block68_data_unref (_data68_);
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_data68_ = NULL;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(ok_func_target_destroy_notify == NULL) ? NULL : (ok_func_target_destroy_notify (ok_func_target), NULL);
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ok_func = NULL;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ok_func_target = NULL;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	ok_func_target_destroy_notify = NULL;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	(dismiss_func_target_destroy_notify == NULL) ? NULL : (dismiss_func_target_destroy_notify (dismiss_func_target), NULL);
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func = NULL;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func_target = NULL;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	dismiss_func_target_destroy_notify = NULL;
#line 119 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return result;
#line 976 "notificationbar.c"
}


BoxesNotificationbar* boxes_notificationbar_construct (GType object_type) {
	BoxesNotificationbar * self = NULL;
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self = (BoxesNotificationbar*) g_object_new (object_type, NULL);
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return self;
#line 986 "notificationbar.c"
}


BoxesNotificationbar* boxes_notificationbar_new (void) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return boxes_notificationbar_construct (BOXES_TYPE_NOTIFICATIONBAR);
#line 993 "notificationbar.c"
}


static void _boxes_notificationbar___lambda47_ (BoxesNotificationbar* self) {
	GList* _tmp0_;
#line 23 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = self->priv->active_notifications;
#line 1001 "notificationbar.c"
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
#line 23 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		w_collection = _tmp0_;
#line 23 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
#line 1009 "notificationbar.c"
			GtkWidget* _tmp1_;
			GtkWidget* w = NULL;
#line 23 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
			_tmp1_ = _g_object_ref0 ((GtkWidget*) w_it->data);
#line 23 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
			w = _tmp1_;
#line 1016 "notificationbar.c"
			{
				GtkContainer* parent = NULL;
				GtkWidget* _tmp2_;
				GtkContainer* _tmp3_;
				GtkContainer* _tmp4_;
				GtkContainer* _tmp5_;
				GtkWidget* _tmp8_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp2_ = w;
#line 24 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp3_ = (GtkContainer*) gtk_widget_get_parent (_tmp2_);
#line 24 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp3_) : NULL);
#line 24 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				parent = _tmp4_;
#line 25 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp5_ = parent;
#line 25 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				if (_tmp5_ != NULL) {
#line 1036 "notificationbar.c"
					GtkContainer* _tmp6_;
					GtkWidget* _tmp7_;
#line 26 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
					_tmp6_ = parent;
#line 26 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
					_tmp7_ = w;
#line 26 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
					gtk_container_remove (_tmp6_, _tmp7_);
#line 1045 "notificationbar.c"
				}
#line 27 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_tmp8_ = w;
#line 27 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				boxes_notificationbar_add_notification (self, _tmp8_);
#line 23 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_g_object_unref0 (parent);
#line 23 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
				_g_object_unref0 (w);
#line 1055 "notificationbar.c"
			}
		}
	}
}


static void __boxes_notificationbar___lambda47__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 22 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_boxes_notificationbar___lambda47_ ((BoxesNotificationbar*) self);
#line 1065 "notificationbar.c"
}


static GObject * boxes_notificationbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesNotificationbar * self;
	GtkStyleContext* _tmp0_;
	BoxesApp* _tmp1_;
#line 12 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_notificationbar_parent_class);
#line 12 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 12 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar);
#line 13 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) self, GTK_ORIENTATION_VERTICAL);
#line 14 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_START);
#line 15 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	gtk_widget_set_halign ((GtkWidget*) self, GTK_ALIGN_CENTER);
#line 16 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 16 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	gtk_style_context_add_class (_tmp0_, "transparent-bg");
#line 18 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	gtk_widget_show ((GtkWidget*) self);
#line 20 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	__g_list_free__g_object_unref0_0 (self->priv->active_notifications);
#line 20 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self->priv->active_notifications = NULL;
#line 22 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_tmp1_ = boxes_app_app;
#line 22 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::page", (GCallback) __boxes_notificationbar___lambda47__g_object_notify, self, 0);
#line 12 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	return obj;
#line 1103 "notificationbar.c"
}


static void boxes_notificationbar_class_init (BoxesNotificationbarClass * klass) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	boxes_notificationbar_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesNotificationbarPrivate));
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_notificationbar_constructor;
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_notificationbar_finalize;
#line 1116 "notificationbar.c"
}


static void boxes_notificationbar_instance_init (BoxesNotificationbar * self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self->priv = BOXES_NOTIFICATIONBAR_GET_PRIVATE (self);
#line 1123 "notificationbar.c"
}


static void boxes_notificationbar_finalize (GObject * obj) {
	BoxesNotificationbar * self;
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar);
#line 8 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	__g_list_free__g_object_unref0_0 (self->priv->active_notifications);
#line 10 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	_g_object_unref0 (self->searchbar);
#line 4 "/home/fborges/checkout/gnome-boxes/src/notificationbar.vala"
	G_OBJECT_CLASS (boxes_notificationbar_parent_class)->finalize (obj);
#line 1137 "notificationbar.c"
}


GType boxes_notificationbar_get_type (void) {
	static volatile gsize boxes_notificationbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_notificationbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesNotificationbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_notificationbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesNotificationbar), 0, (GInstanceInitFunc) boxes_notificationbar_instance_init, NULL };
		GType boxes_notificationbar_type_id;
		boxes_notificationbar_type_id = g_type_register_static (gtk_grid_get_type (), "BoxesNotificationbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_notificationbar_type_id__volatile, boxes_notificationbar_type_id);
	}
	return boxes_notificationbar_type_id__volatile;
}



